package MT::Plugin::DefaultSortKeyChanger;

use strict;
use base qw( MT::Plugin );
use MT;

our $VERSION = '0.01';

my $plugin = __PACKAGE__->new({
    id => 'DefaultSortKeyChanger',
    name => 'DefaultSortKeyChanger',
    version => $VERSION,
    description => '<MT_TRANS phrase="DefaultSortKeyChanger.">',
    author_name => 'Yujiro Araki',
    author_link => 'http://www.koikikukan.com/',
    l10n_class  => 'DefaultSortKeyChanger::L10N',
    blog_config_template => 'blog_config.tmpl',
    settings => new MT::PluginSettings(
        [   [   'default_sort_key',
                { Default => 'modified_on', Scope => 'blog' }
            ]
        ]),
});
MT->add_plugin( $plugin );

*MT::CMS::ContentType::_make_content_data_listing_screens = \&plugin_make_content_data_listing_screens;

sub plugin_make_content_data_listing_screens {

my $app = shift;
    my $props = {};

    my $plugin = MT->component("DefaultSortKeyChanger");

    my $iter = MT->model('content_type')->load_iter;
    while ( my $ct = $iter->() ) {

        my $key = 'content_data.content_data_' . $ct->id;
        $props->{$key} = {
            primary          => 'id',
            default_sort_key => sub {
                my $blog_id = $ct->blog_id;
                return $plugin->get_config_value('default_sort_key', 'blog:' . $blog_id) || 'modified_on';
            },
            screen_label     => sub {
                MT->translate( 'Manage [_1]', $ct->name );
            },
            object_label        => $ct->name,
            object_label_plural => $ct->name,
            object_type         => 'content_data',
            scope_mode          => 'this',
            use_filters         => 0,
            view                => [ 'website', 'blog' ],
            condition           => sub {
                my ($app) = @_;
                my $blog_id = $app->blog ? $app->blog->id : 0;
                return $app->trans_error('Invalid request.')
                    unless $blog_id == $ct->blog_id;
                1;
            },
            permission => sub {
                return [
                    'access_to_content_data_list_' . $ct->unique_id,
                    'access_to_content_data_list',
                ];
            },
            feed_link => sub {

                # TODO: fix permission
                my ($app) = @_;
                return 1 if $app->user->is_superuser;

                if ( $app->blog ) {
                    return 1
                        if $app->user->can_do( "get_${key}_feed",
                        at_least_one => 1 );
                }
                else {
                    my $iter = MT->model('permission')->load_iter(
                        {   author_id => $app->user->id,
                            blog_id   => { not => 0 },
                        }
                    );
                    my $cond;
                    while ( my $p = $iter->() ) {
                        $cond = 1, last
                            if $p->can_do("get_${key}_feed");
                    }
                    return $cond ? 1 : 0;
                }
                0;
            },
        };
    }

    return $props;
}

1;
